# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"OmekaAPIClient": "api.ipynb"}

modules = ["api.py"]

doc_url = "https://wragge.github.io/omeka_s_tools/"

git_url = "https://github.com/wragge/omeka_s_tools/tree/master/"

def custom_doc_links(name): return None
